@@ -14,16 +14,31 @@
 # limitations under the License.
 
 
+# CDC绑定VPC失败。
+FAILEDOPERATION_CDCBINDVPCFAIL = 'FailedOperation.CdcBindVpcFail'
+
 # 删除site失败。
 FAILEDOPERATION_FAILDELETESITE = 'FailedOperation.FailDeleteSite'
 
+# 镜像的状态不支持镜像同步
+FAILEDOPERATION_INVALIDIMAGESTATE = 'FailedOperation.InvalidImageState'
+
+# 内部错误。
+INTERNALERROR = 'InternalError'
+
+# 当前镜像已经在本地专用集群中缓存
+INVALIDPARAMETER_IMAGEISCACHEDINCDC = 'InvalidParameter.ImageIsCachedInCdc'
+
+# 当前镜像没有在本地专用集群中缓存
+INVALIDPARAMETER_IMAGENOTCACHEINCDC = 'InvalidParameter.ImageNotCacheInCdc'
+
 # 该机型暂不支持。
 INVALIDPARAMETER_INSTANCETYPENOTSUPPORT = 'InvalidParameter.InstanceTypeNotSupport'
 
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
-# ccdb返回结果不为0。
+# 无效的AppId
 INVALIDPARAMETERVALUE_INVALIDAPPIDFORMAT = 'InvalidParameterValue.InvalidAppIdFormat'
 
 # 本地专用集群COS大小不正确。
@@ -50,6 +65,9 @@ INVALIDPARAMETERVALUE_ZONEMISMATCHREGION = 'InvalidParameterValue.ZoneMismatchRe
 # 当前可用区暂未支持。
 INVALIDPARAMETERVALUE_ZONENOTSUPPORTED = 'InvalidParameterValue.ZoneNotSupported'
 
+# 当前集群的镜像任务数量已达上限
+LIMITEXCEEDED_CDCIMAGETASKQUOTA = 'LimitExceeded.CdcImageTaskQuota'
+
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
@@ -73,3 +91,6 @@ RESOURCENOTFOUND_INVALIDSITEID = 'ResourceNotFound.InvalidSiteId'
 
 # 不支持非CUSTOMER类型的app id。
 UNSUPPORTEDOPERATION_NONCUSTOMERAPPIDNOTSUPPORT = 'UnsupportedOperation.NonCustomerAppIdNotSupport'
+
+# 账户不支持cdc镜像同步，需要先加白
+UNSUPPORTEDOPERATION_SYNCCDCIMAGENOTSUPPORT = 'UnsupportedOperation.SyncCdcImageNotSupport'
